@@ -8,6 +8,7 @@ import pickle
 import datetime
 import time
 import alarm
+import dbus
 
 JOB_DIR = os.environ['HOME'] + "/.config/alarmed/jobs/"
 PRESET_DIR = os.environ['HOME'] + "/.config/alarmed/presets/"
@@ -149,35 +150,7 @@ def loadPreset(preset_name):
     return preset
 
 def getAvailableProfiles():
-        """Checks if tweakr is installed and returns the profiles"""
-        try:
-            print "a"
-            state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
-                                 stdout=subprocess.PIPE, stderr=open(os.devnull, "w")).communicate(
-                                 )[0].split("\n")[5].split()[0]
-            print "b"
-            if state == "ii":
-                try:
-                    profiles = []
-                    tweaker_profiles = subprocess.Popen(
-                            ['gconftool-2', '--all-dirs', '/system/tweakr'],
-                            stdout=subprocess.PIPE).communicate(
-                            )[0].split("\n")
-                    for profile in tweaker_profiles:
-                        try:
-                            profiles.append(profile.split("/")[3])
-                        except IndexError:
-                            pass
-                    if len(profiles) == 0:
-                        profiles = ["General"]
-                except IndexError:
-                    profiles = ["General"]
-            else:
-                profiles = ["General"]
-        except IndexError:
-            profiles = ["General"]
-        profiles.append("Silent")
-        return profiles
+        return list(dbus.Interface(dbus.SessionBus().get_object('com.nokia.profiled', '/com/nokia/profiled'), 'com.nokia.profiled').get_profiles())
  
 def generateEventString(eventInfo):
     """Generates a single string from event data"""
@@ -230,31 +203,101 @@ def interpretCronString(string):
             return False, ("cronstring - " + o.cron + 
                            " doesn't have 5 parts")
         min = cronstring[0].split(",")
-        if min != ["*"]:
+        if min[0][:2]=="*/":
+            n=int(min[0][2:])
+            if n!=0:
+                 min=[str(i) for i in range(0,59) if not i%n]
+            else:
+                 return False, "Division by 0"
+        elif min[0].count("-")==1:
+            ind=min[0].index("-")
+            i=int(min[0][:ind])
+            j=int(min[0][ind+1:])
+            if 0 <= i <= j <= 59:
+                 min=[str(i) for i in range(i,j+1)]
+            else:
+                 return False, "Bad interval"
+        elif min != ["*"]:
             for m in min:
                 if not (0 <= int(m) <= 59):
                     return False, ("minute part of cronstring - " + m +
                                   " - is not between 0 and 59 or *")
         hour = cronstring[1].split(",")
-        if hour != ["*"]:
+        if hour[0][:2]=="*/":
+            n=int(hour[0][2:])
+            if n!=0:
+                 hour=[str(i) for i in range(0,23) if not i%n]
+            else:
+                 return False, "Division by 0"
+        elif hour[0].count("-")==1:
+            ind=hour[0].index("-")
+            i=int(hour[0][:ind])
+            j=int(hour[0][ind+1:])
+            if 0 <= i <= j <= 23:
+                 hour=[str(i) for i in range(i,j+1)]
+            else:
+                 return False, "Bad interval"
+        elif hour != ["*"]:
             for h in hour:
                 if not (0 <= int(h) <= 23):
                     return False, ("hour part of cronstring - " + h +
                                   " - is not between 0 and 23 or *")
         dom = cronstring[2].split(",")
-        if dom != ["*"]:
+        if dom[0][:2]=="*/":
+            n=int(dom[0][2:])
+            if n!=0:
+                 dom=[str(i) for i in range(1,31) if not i%n]
+            else:
+                 return False, "Division by 0"
+        elif dom[0].count("-")==1:
+            ind=dom[0].index("-")
+            i=int(dom[0][:ind])
+            j=int(dom[0][ind+1:])
+            if 1 <= i <= j <= 31:
+                 dom=[str(i) for i in range(i,j+1)]
+            else:
+                 return False, "Bad interval"
+        elif dom != ["*"]:
             for d in dom:
                 if not (1 <= int(d) <= 31):
                     return False, ("day of month part of cronstring - "
                                  + d +" - is not between 1 and 31 or *")
         month = cronstring[3].split(",")
-        if month != ["*"]:
+        if month[0][:2]=="*/":
+            n=int(month[0][2:])
+            if n!=0:
+                 month=[str(i) for i in range(1,12) if not i%n]
+            else:
+                 return False, "Division by 0"
+        elif month[0].count("-")==1:
+            ind=month[0].index("-")
+            i=int(month[0][:ind])
+            j=int(month[0][ind+1:])
+            if 1 <= i <= j <= 12:
+                 month=[str(i) for i in range(i,j+1)]
+            else:
+                 return False, "Bad interval"
+        elif month != ["*"]:
             for m in month:
                 if not (1 <= int(m) <= 12):
                     return False, ("month part of cronstring - " + m +
                                   " - is not between 0 and 12 or *")
         dow = cronstring[4].split(",")
-        if dow != ["*"]:
+        if dow[0][:2]=="*/":
+            n=int(dow[0][2:])
+            if n!=0:
+                 dow=[str(i) for i in range(0,6) if not i%n]
+            else:
+                 return False, "Division by 0"
+        elif dow[0].count("-")==1:
+            ind=dow[0].index("-")
+            i=int(dow[0][:ind])
+            j=int(dow[0][ind+1:])
+            if 0 <= i <= j <= 6:
+                 dow=[str(i) for i in range(i,j+1)]
+            else:
+                 return False, "Bad interval"
+        elif dow != ["*"]:
             for d in dow:
                 if not (0 <= int(d) <= 6):
                     return False, ("day of week part of cronstring - " +
@@ -262,7 +305,7 @@ def interpretCronString(string):
     except ValueError:
         return False, ("Cron string " + string +
                        "contains invalid characters")
-    return True, cronstring
+    return True,[",".join(min),",".join(hour),",".join(dom),",".join(month),",".join(dow)]
     
 def interpretDateString(string):
     """Checks if date syntax string is valid and returns ttime"""
@@ -289,23 +332,30 @@ def makeEvent(eventInfo, old_id):
         dt = datetime.datetime.fromtimestamp(eventInfo["ttime"])
     except KeyError:
         event.alarm_time = -1
-    event.appid = str(eventInfo["title"].replace(" ", "_"))
+    event.appid = "alarmed"
     t = loadFieldsDict()["types"]
+    s = loadFieldsDict()["schedules"]
+    add_textdomain = False
     #set action depending on type
     if eventInfo["type"] == t["alarm_type"]:
+        if eventInfo["schedule"] in (s["daily"], s["weekly"]):
+            event.appid = "worldclock_alarmd_id"
+            event.icon = "qgn_list_hclk_alarm"
         action_snooze, action_stop = event.add_actions(2)
         action_stop.flags |= (alarm.ACTION_WHEN_RESPONDED |
                               alarm.ACTION_TYPE_NOP)
         action_stop.label = 'cloc_bd_stop' #'Stop'
         action_snooze.flags |= (alarm.ACTION_WHEN_RESPONDED |
                                 alarm.ACTION_TYPE_SNOOZE)
-        action_snooze.label = 'cloc bd alarm notification snooze' #'Snooze'
-        event.message = eventInfo["title"]
+        action_snooze.label = 'cloc_bd_alarm_notification_snooze' #'Snooze'
+        event.message = eventInfo["title"].encode("utf-8")
+        event.title = eventInfo["title"].encode("utf-8")
+        add_textdomain = True
     elif eventInfo["type"] == t["exec_type"]:
         action = event.add_actions(1)[0]
         action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
                          alarm.ACTION_TYPE_EXEC)
-        action_string = str(eventInfo["content"]).replace("'","'\\''")
+        action_string = eventInfo["content"].replace("'","'\\''").encode("utf-8")
         action_string = "/bin/ash -c '" + action_string + "'"
         action.command = action_string
         
@@ -332,25 +382,7 @@ def makeEvent(eventInfo, old_id):
         action = event.add_actions(1)[0]
         action.flags |= (alarm.ACTION_WHEN_TRIGGERED | 
                          alarm.ACTION_TYPE_EXEC)
-        if eventInfo["content"] == "Silent":
-            action.command = str(
-                               "/opt/alarmed/profileswitcher.sh silent")
-        else:
-            try:
-                state = subprocess.Popen(['dpkg-query', '-l', 'tweakr'], 
-                               stdout=subprocess.PIPE, stderr=open(os.devnull, "w")).communicate(
-                               )[0].split("\n")[5].split()[0]
-                if state == "ii":
-                    action.command = str(
-                              "/opt/alarmed/tweakrprofileswitcher.sh " +
-                              eventInfo["content"])
-                else:
-                    action.command = str(
-                              "/opt/alarmed/profileswitcher.sh general")
-            except IndexError:
-                action.command = str(
-                              "/opt/alarmed/profileswitcher.sh general")
-    s = loadFieldsDict()["schedules"]
+        action.command = ("/opt/alarmed/profileswitcher.sh %s" % eventInfo["content"]).encode("utf-8")
     if eventInfo["schedule"] == s["every_minute"]:
         recurrence = event.add_recurrences(1)[0]
         event.recurrences_left = -1
@@ -537,6 +569,12 @@ def makeEvent(eventInfo, old_id):
         new_id = str(alarm.add_event(event))
     except alarm.InvalidEventException:
         return "invalid"
+    if add_textdomain:
+        from ctypes import cdll
+        dll = cdll.LoadLibrary("/usr/lib/libalarm.so.2")
+        ev = dll.alarmd_event_get(int(new_id))
+        dll.alarm_event_set_attr_string(ev, "textdomain", "osso-clock")
+        new_id = str(dll.alarmd_event_update(ev))
     #save the pickled event info
     if old_id:
         deleteEvent(int(old_id))
