@@ -54,8 +54,8 @@ class AlarmedGUI(QtGui.QWidget):
     def addEventToList(self, eventInfo, editing=False):
         """Adds a QListWidgetItem to the list of events"""
         if editing:
-            self.eventList.removeItemWidget(
-                           self.eventList.currentItem())
+            self.eventList.takeItem(
+                           self.eventList.currentRow())
         newEventTitle, newEventContent = alarmed_backend.generateEventString(eventInfo)
         newEvent = QtGui.QListWidgetItem(newEventTitle + "\n" + newEventContent)
         newEvent.setFlags(newEvent.flags() | QtCore.Qt.ItemIsUserCheckable | QtCore.Qt.ItemIsSelectable | QtCore.Qt.ItemIsEnabled)
@@ -74,8 +74,8 @@ class AlarmedGUI(QtGui.QWidget):
         if (self.eventList.currentItem()):
             alarmed_backend.deleteEvent(int(
              self.eventList.currentItem().eventInfo["id"]))
-            self.eventList.removeItemWidget(
-             self.eventList.currentItem())
+            self.eventList.takeItem(
+             self.eventList.currentRow())
         else:
             self.showError('''<font color="#000000">Select an item first</font>''')
 
@@ -331,7 +331,9 @@ class AlarmedGUI(QtGui.QWidget):
             i = self.profilePicker.findText(
              self.eventList.currentItem().eventInfo["content"])
             if i == -1:
-                self.showError('''<font color="#000000">This event has become invalid because you (un)installed tweakr.</font>''')
+                self.showError(
+                    '''<font color="#000000">This event has become invalid because you deleted profile %s.</font>'''
+                    % self.eventList.currentItem().eventInfo["content"])
             self.profilePicker.setCurrentIndex(i)
             self.profilePicker.show()
 
@@ -585,8 +587,7 @@ class AlarmedGUI(QtGui.QWidget):
             dateTime = dateTime.addSecs(secs)
             eventInfo["ttime"] = int(dateTime.toTime_t())
             eventInfo["number"] = int(self.numberPicker.value())
-            eventInfo["interval"] = str(
-                                      self.intervalPicker.currentText())
+            eventInfo["interval"] = str(self.intervalPicker.currentText())
         elif self.schedulePicker.currentText() == s["next"]:
             day = self.rWeekdayPicker.currentText()
             if day == mon: day = 1
